# Django REST Framework Tree Router

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Python Version][version-badge]][pypi]

```shell
pip install drf-tree-router
```

---

**Documentation**: [https://mrthearman.github.io/drf-tree-router/](https://mrthearman.github.io/drf-tree-router/)

**Source Code**: [https://github.com/MrThearMan/drf-tree-router/](https://github.com/MrThearMan/drf-tree-router/)

---

A Django REST Framework router that can be nested with other routers to create a tree-like structure
of your API endpoints. The router also accepts APIViews in addition to ViewSets.

[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/drf-tree-router/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/workflow/status/MrThearMan/drf-tree-router/Tests
[pypi-badge]: https://img.shields.io/pypi/v/drf-tree-router
[licence-badge]: https://img.shields.io/github/license/MrThearMan/drf-tree-router
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/drf-tree-router
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/drf-tree-router
[version-badge]: https://img.shields.io/pypi/pyversions/drf-tree-router

[coverage]: https://coveralls.io/github/MrThearMan/drf-tree-router?branch=main
[status]: https://github.com/MrThearMan/drf-tree-router/actions/workflows/main.yml
[pypi]: https://pypi.org/project/drf-tree-router
[licence]: https://github.com/MrThearMan/drf-tree-router/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/drf-tree-router/commits/main
[issues]: https://github.com/MrThearMan/drf-tree-router/issues
